##  Creating Approval To-Dos
An approval to-do allows users to review and respond to tasks with approval or rejection. You can preset the approval or rejection decisions to automatically complete certain actions in the fact sheets. It streamlines decision-making and enables you to enforce and track governance workflows.
Approval to-dos are created through the automation feature in the administration area. When the automation is triggered, defined approval to-dos are automatically created and assigned to relevant users.
Summarily it involves defining the trigger event for the automation, setting the condition if necessary, and creating approval to-do as an action of the automation.
To create an approval to-do, follow these steps:
  1. In the workspace Administration area, select the Automations section under Advanced Settings.
  2. Click New Automation.
  3. Configure the trigger and, if needed, conditions for the automation.
![Example: Automation Creating an Approval To-Do Based on the Creation of an Application Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c9ecf7a4410149afed8fc06b27c2b_LowRes.png)
Example: Automation Creating an Approval To-Do Based on the Creation of an Application Fact Sheet
  4. To define the actions of the automation:
    1. Click +Add Action and select Create To-Do: Approval from the drop-down menu.
    2. Fill in the necessary information regarding the assignee, fact sheet, and fact sheet subscription.
    3. Define action to be taken if the approval to-do is rejected and action to be taken if the approval to-do is approved. To define an action for approval, you need to add one more action item by clicking on the +Add Action button.
![Example: Defining the Actions of Automation for a Rejection or Approval of To-Do](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2745da0a7a44101495f0a11936d7da07_LowRes.png)
Example: Defining the Actions of Automation for a Rejection or Approval of To-Do
  5. Select Save and run Automation.


Based on the trigger and conditions of the automation, an approval to-do will be created on a fact sheet with the relevant assignees.
![Approval To-Do in Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274647b17a441014b356ecada082d003_LowRes.png)
Approval To-Do in Fact Sheet
